#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class max_iter_per_timestep_count(Integer):
    """
    Specify maximum number of iterations per timestep.
    """

    fluent_name = "max-iter-per-timestep-count"

    return_type = "<object object at 0x7efbc462c1e0>"
