#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class blade_pitch_cyclic_sin(Real):
    """
    Set magnitude of sin component of blade's cyclic pitch angle:.
    """

    fluent_name = "blade-pitch-cyclic-sin"

    return_type = "<object object at 0x7f80684c64d0>"
