#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .default import default as default_cls
from .reverse import reverse as reverse_cls

class curve_length(Group):
    """
    'curve_length' child.
    """

    fluent_name = "curve-length"

    child_names = \
        ['option', 'default', 'reverse']

    _child_classes = dict(
        option=option_cls,
        default=default_cls,
        reverse=reverse_cls,
    )

    return_type = "<object object at 0x7f4ba6cf7280>"
