#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class particle_creation_every_particle_step_enabled(Boolean):
    """
    Create particles every particle time step (else every fluid time step)?.
    """

    fluent_name = "particle-creation-every-particle-step-enabled?"

    return_type = "<object object at 0x7efc281d84f0>"
