#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .sample import sample as sample_cls
from .variable import variable as variable_cls

class compute_sample(Command):
    """
    Compute minimum/maximum of a sample variable.
    
    Parameters
    ----------
        sample : str
            'sample' child.
        variable : str
            'variable' child.
    
    """

    fluent_name = "compute-sample"

    argument_names = \
        ['sample', 'variable']

    _child_classes = dict(
        sample=sample_cls,
        variable=variable_cls,
    )

    return_type = "<object object at 0x7f4ba6cf7d50>"
